{ config, ... }:

{
  users.users."nginx".home = "/var/lib/nginx";

  services.nginx = {
    enable = true;
    virtualHosts =
      let anubisConf = [
          {
            addr = "localhost";
            port = 8888;
          }
      ];
      in {
      # redirection install-party
      "install-party.crans.fr" = {
        enableACME = true;
        forceSSL = true;
        serverAliases = [
          "i-p.crans.org"
          "adopteunmanchot.crans.org"
          "adopteunpingouin.crans.org"
          "i-p.crans.fr"
          "adopteunmanchot.crans.fr"
          "adopteunpingouin.crans.fr"
          "i-p.crans.eu"
          "install-party.crans.eu"
          "adopteunmanchot.crans.eu"
          "adopteunpingouin.crans.eu"
        ];
        extraConfig = ''
          return 301 https://install-party.crans.org$request_uri;
        '';
      };

      # redirection mediawiki
      "mediawiki.crans.fr" = {
        enableACME = true;
        forceSSL = true;
        serverAliases = [
          "mediakiwi.crans.org"
          "mediakiwi.crans.fr"
          "mediakiwi.crans.eu"
          "mediawiki.crans.eu"
        ];
        extraConfig = ''
          return 301 https://mediawiki.crans.org$request_uri;
        '';
      };

      # redirection wiki
      "wiki.crans.fr" = {
        enableACME = true;
        forceSSL = true;
        serverAliases = [
          "wikipedia.crans.org"
          "wikipedia.crans.fr"
          "wikipedia.crans.eu"
          "wiki.crans.eu"
        ];
        extraConfig = ''
          return 301 https://wiki.crans.org$request_uri;
        '';
      };

      # redirection anubis
      "anubis" = {
        enableACME = true;
        forceSSL = true;
        locations."/" = {
          proxyPass = "http://${config.services.anubis.instances."muraille".settings.BIND}";
        };
        serverName = "install-party.crans.org";
        serverAliases = [
          "mediawiki.crans.org"
          "wiki.crans.org"
        ];
      };

      # install-party
      "install-party.crans.org" = {
        root = "/var/www/install-party.crans.org";
        listen = anubisConf;
      };

      # mediawiki
      "mediawiki.crans.org" = {
        locations."/".proxyPass = "http://172.16.10.144";
        listen = anubisConf;
      };

      # wiki
      "wiki.crans.org" = {
        locations."/".proxyPass = "http://172.16.10.161";
        listen = anubisConf;
      };
    };
  };
}
